skhubness.neighbors.NeighborhoodComponentsAnalysis
==================================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: NeighborhoodComponentsAnalysis

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NeighborhoodComponentsAnalysis.__init__
      ~NeighborhoodComponentsAnalysis.fit
      ~NeighborhoodComponentsAnalysis.fit_transform
      ~NeighborhoodComponentsAnalysis.get_params
      ~NeighborhoodComponentsAnalysis.set_params
      ~NeighborhoodComponentsAnalysis.transform
   
   

   
   
   